@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_codebuild._jsii
 import aws_cdk.aws_codedeploy._jsii
@@ -20,9 +20,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@cloudcomponents/cdk-blue-green-container-deployment",
-    "1.0.34",
+    "1.0.35",
     __name__[0:-6],
-    "cdk-blue-green-container-deployment@1.0.34.jsii.tgz",
+    "cdk-blue-green-container-deployment@1.0.35.jsii.tgz",
 )
 
 __all__ = [
